/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.jackrabbit.oak.osgi;

import javax.annotation.CheckForNull;

import org.apache.jackrabbit.oak.spi.commit.CompositeEditorProvider;
import org.apache.jackrabbit.oak.spi.commit.Editor;
import org.apache.jackrabbit.oak.spi.commit.EditorProvider;
import org.apache.jackrabbit.oak.spi.state.NodeBuilder;
import org.apache.jackrabbit.oak.spi.state.NodeState;

/**
 * This editor provider combines all editors of all available OSGi editor
 * providers.
 */
public class OsgiEditorProvider
        extends AbstractServiceTracker<EditorProvider>
        implements EditorProvider {

    public OsgiEditorProvider() {
        super(EditorProvider.class);
    }

    //----------------------------------------------------< EditorProvider >--

    @Override
    @CheckForNull
    public Editor getRootEditor(
            NodeState before, NodeState after, NodeBuilder builder) {
        EditorProvider provider =
                CompositeEditorProvider.compose(getServices());
        return provider.getRootEditor(before, after, builder);
    }
}
