/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.spi.security;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.apache.jackrabbit.oak.spi.security.authentication.AuthenticationConfiguration;
import org.apache.jackrabbit.oak.spi.security.authorization.AccessControlConfiguration;
import org.apache.jackrabbit.oak.spi.security.principal.PrincipalConfiguration;
import org.apache.jackrabbit.oak.spi.security.privilege.PrivilegeConfiguration;
import org.apache.jackrabbit.oak.spi.security.user.UserConfiguration;

/**
 * SecurityProvider... TODO
 */
public interface SecurityProvider {

    @Nonnull
    ConfigurationParameters getConfiguration(@Nullable String name);

    @Nonnull
    Iterable<SecurityConfiguration> getSecurityConfigurations();

    @Nonnull
    AuthenticationConfiguration getAuthenticationConfiguration();

    @Nonnull
    AccessControlConfiguration getAccessControlConfiguration();

    @Nonnull
    PrivilegeConfiguration getPrivilegeConfiguration();

    @Nonnull
    UserConfiguration getUserConfiguration();

    @Nonnull
    PrincipalConfiguration getPrincipalConfiguration();
}
